Entry

Struct Entry 

pub struct Entry { /* private fields */ }
A combination of type, count, and offset.

In a TIFF the data offset portion of an entry is used for inline data in case the length of the encoded value does not exceed the size of the offset field. Since the size of the offset field depends on the file kind (4 bytes for standard TIFF, 8 bytes for BigTIFF) the interpretation of this struct is only complete in combination with file metadata.

Implementations

Source

impl Entry

pub fn new(type_: Type, count: u32, offset: [u8; 4]) -> Entry

Create a new entry fit to be added to a standard TIFF IFD.

pub fn new_u64(type_: Type, count: u64, offset: [u8; 8]) -> Entry

Create a new entry with data for a Big TIFF IFD.

pub fn field_type(&self) -> Type

pub fn count(&self) -> u64